package club.dawdler.user.controller;

import java.util.List;

import com.anywide.dawdler.clientplug.web.annotation.Controller;
import com.anywide.dawdler.clientplug.web.annotation.RequestMapping;
import com.anywide.dawdler.clientplug.web.annotation.RequestMapping.RequestMethod;
import com.anywide.dawdler.clientplug.web.annotation.ResponseBody;
import com.anywide.dawdler.core.result.BaseResult;
import com.anywide.dawdler.core.result.PageResult;
import com.anywide.dawdler.local.service.annotation.LocalService;

import club.dawdler.user.entity.User;
import club.dawdler.user.service.UserService;

@Controller
@RequestMapping("/user")
public class UserController {
	@LocalService
	private UserService userService;

	/**
	 * 
	 * 查询[用户表]列表
	 * 
	 * @Copyright dawlder 2024-10-23
	 *            <p>
	 *            Company: dawlder
	 *            </p>
	 * @author srchen
	 * @date 2024年10月23日 14:18:22
	 * @version 1.0
	 * @param pageOn
	 * @param user
	 */
	@ResponseBody
	@RequestMapping(value = "/list", method = RequestMethod.GET)
	public PageResult<List<User>> list(Integer pageOn, User user) {
		int row = 10;
		if (pageOn == null) {
			pageOn = 1;
		}
		return userService.selectPageList(user, pageOn, row);
	}

	/**
	 * 
	 * 查询[用户表]
	 * 
	 * @Copyright dawlder 2024-10-23
	 *            <p>
	 *            Company: dawlder
	 *            </p>
	 * @author srchen
	 * @date 2024年10月23日 14:18:22
	 * @version 1.0
	 * @param id 用户ID
	 */
	@ResponseBody
	@RequestMapping(value = "/info", method = RequestMethod.GET)
	public BaseResult<User> info(Integer id) {
		return userService.selectByPrimaryKey(id);
	}

	/**
	 * 
	 * 更新[用户表]
	 * 
	 * @Copyright dawlder 2024-10-23
	 *            <p>
	 *            Company: dawlder
	 *            </p>
	 * @author srchen
	 * @date 2024年10月23日 14:18:22
	 * @version 1.0
	 * @param user
	 */
	@ResponseBody
	@RequestMapping(value = "/update", method = RequestMethod.PUT)
	public BaseResult<Void> update(User user) {
		int count = userService.updateByPrimaryKeySelective(user);
		BaseResult<Void> baseResult;
		if (count > 0) {
			baseResult = new BaseResult<>("更新成功!", true);
		} else {
			baseResult = new BaseResult<>("更新失败!", false);
		}
		return baseResult;
	}

	/**
	 * 
	 * 插入[用户表]
	 * 
	 * @Copyright dawlder 2024-10-23
	 *            <p>
	 *            Company: dawlder
	 *            </p>
	 * @author srchen
	 * @date 2024年10月23日 14:18:22
	 * @version 1.0
	 * @param user
	 */
	@ResponseBody
	@RequestMapping(value = "/insert", method = RequestMethod.POST)
	public BaseResult<Void> insert(User user) {
		int count = userService.insertSelective(user);
		BaseResult<Void> baseResult;
		if (count > 0) {
			baseResult = new BaseResult<>("插入成功!", true);
		} else {
			baseResult = new BaseResult<>("插入失败!", false);
		}
		return baseResult;
	}

	/**
	 * 
	 * 删除[用户表]
	 * 
	 * @Copyright dawlder 2024-10-23
	 *            <p>
	 *            Company: dawlder
	 *            </p>
	 * @author srchen
	 * @date 2024年10月23日 14:18:22
	 * @version 1.0
	 * @param id 用户ID
	 */
	@ResponseBody
	@RequestMapping(value = "/delete", method = RequestMethod.DELETE)
	public BaseResult<Void> delete(Integer id) {
		int count = userService.deleteByPrimaryKey(id);
		BaseResult<Void> baseResult;
		if (count > 0) {
			baseResult = new BaseResult<>("删除成功!", true);
		} else {
			baseResult = new BaseResult<>("删除失败!", false);
		}
		return baseResult;
	}
}